package com.ynet.life.util;

import java.sql.Time;
import java.sql.Timestamp;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

/* loaded from: com_ynet_life_util.jar:com/ynet/life/util/SqlDateTime.class */
public class SqlDateTime {
    private Calendar calendar;
    public static int MILLIS_OF_ONE_DAY = 86400000;
    private static SimpleDateFormat formator = new SimpleDateFormat();
    public static final int DAY = 3;
    public static final int WEEK = 2;
    public static final int MONTH = 1;
    public static final int YEAR = 0;
    public static final int HOUR = 0;
    public static final int MINUTE = 1;
    public static final int SECOND = 2;

    public SqlDateTime() {
        this.calendar = Calendar.getInstance();
    }

    public SqlDateTime(int yyyy, int mm, int dd) {
        this.calendar = Calendar.getInstance();
        this.calendar.setLenient(false);
        this.calendar.set(yyyy, mm - 1, dd);
        this.calendar.getTime();
        this.calendar.setLenient(true);
    }

    public SqlDateTime(String dateStr, String pattern) throws ParseException {
        formator.applyPattern(pattern);
        Date a = formator.parse(dateStr);
        this.calendar = Calendar.getInstance();
        this.calendar.setTime(a);
    }

    public SqlDateTime(Date in) {
        this.calendar = Calendar.getInstance();
        this.calendar.setTime(in);
    }

    private static java.sql.Date getDate(Calendar cc) {
        cc.set(14, 0);
        cc.set(11, 0);
        cc.set(12, 0);
        cc.set(13, 0);
        return new java.sql.Date(cc.getTime().getTime());
    }

    private static Timestamp getDateTime(Calendar cal) {
        cal.set(14, 0);
        return new Timestamp(cal.getTime().getTime());
    }

    public int getDay() {
        return this.calendar.get(5);
    }

    public int getDayOfWeek() {
        int ret = this.calendar.get(7) - 1;
        if (ret == 0) {
            return 7;
        }
        return ret;
    }

    public int getHour() {
        return this.calendar.get(11);
    }

    public int getMinute() {
        return this.calendar.get(12);
    }

    public int getMonth() {
        return this.calendar.get(2) + 1;
    }

    public int getSecond() {
        return this.calendar.get(13);
    }

    private static Time getTime(Calendar cal) {
        cal.set(14, 0);
        long msInOneDay = cal.getTime().getTime() % MILLIS_OF_ONE_DAY;
        return new Time(msInOneDay);
    }

    public int getWeek() {
        return this.calendar.get(4);
    }

    public int getYear() {
        return this.calendar.get(1);
    }

    public boolean isMonthStart() {
        return this.calendar.get(5) == 1;
    }

    public boolean isWeekStart() {
        return this.calendar.get(7) == 2;
    }

    public boolean isYearStart() {
        return this.calendar.get(5) == 1 && this.calendar.get(2) == 0;
    }

    public static void main(String[] args) throws Exception {
        SqlDateTime d = new SqlDateTime(new Date());
        System.out.println(d.rollDate(0, 1, 0));
    }

    public SqlDateTime roll(int years, int months, int days, int hours, int minutes, int seconds) {
        Calendar cc = this.calendar;
        cc.add(1, years);
        cc.add(2, months);
        cc.add(5, days);
        cc.add(11, hours);
        cc.add(12, minutes);
        cc.add(13, seconds);
        return this;
    }

    public SqlDateTime rollDate(int years, int months, int days) {
        return roll(years, months, days, 0, 0, 0);
    }

    public SqlDateTime rollTime(int hours, int minutes, int seconds) {
        return roll(0, 0, 0, hours, minutes, seconds);
    }

    public java.sql.Date toDate() {
        return getDate((Calendar) this.calendar.clone());
    }

    public java.sql.Date toDate(int mode, int num) {
        Calendar cc = (Calendar) this.calendar.clone();
        switch (mode) {
            case 0:
                cc.set(5, 1);
                cc.set(2, 0);
                cc.add(1, num);
                break;
            case 1:
                cc.set(5, 20);
                cc.add(2, num);
                break;
            case 2:
                cc.add(5, ((num * 7) + 1) - getDayOfWeek());
                break;
            case DAY /* 3 */:
                cc.add(5, num);
                break;
        }
        return getDate(cc);
    }

    public java.sql.Date toDate(int mode, int unit, int num) {
        int num0 = 0;
        switch (mode) {
            case 0:
                num0 = (unit * num) - (getYear() % unit);
                break;
            case 1:
                num0 = (unit * num) - ((getMonth() - 1) % unit);
                break;
            case 2:
                num0 = (unit * num) - ((getWeek() - 1) % unit);
                break;
            case DAY /* 3 */:
                num0 = (unit * num) - ((getDay() - 1) % unit);
                break;
        }
        return toDate(mode, num0);
    }

    public Timestamp toDateTime() {
        return getDateTime(this.calendar);
    }

    public Timestamp toDateTime(int num) {
        Calendar cc = (Calendar) this.calendar.clone();
        cc.set(11, 0);
        cc.set(12, 0);
        cc.set(13, 0);
        cc.add(5, num);
        return getDateTime(cc);
    }

    public Timestamp toDateTime(int mode, int num) {
        Calendar cc = (Calendar) this.calendar.clone();
        switch (mode) {
            case 0:
                cc.add(11, num);
                cc.set(12, 0);
                cc.set(13, 0);
                break;
            case 1:
                cc.add(12, num);
                cc.set(13, 0);
                break;
            case 2:
                cc.add(13, num);
                break;
        }
        return getDateTime(cc);
    }

    public Timestamp toDateTime(int mode, int unit, int num) {
        int num0 = 0;
        switch (mode) {
            case 0:
                num0 = (unit * num) - (getHour() % unit);
                break;
            case 1:
                num0 = (unit * num) - (getMinute() % unit);
                break;
            case 2:
                num0 = (unit * num) - (getSecond() % unit);
                break;
        }
        return toDateTime(mode, num0);
    }

    public String toString() {
        return toString("yyyy-MM-dd HH:mm:ss.SSS");
    }

    public String toString(String pattern) {
        formator.applyPattern(pattern);
        return formator.format(this.calendar.getTime());
    }

    public static String toString(Date in, String pattern) {
        formator.applyPattern(pattern);
        return formator.format(in);
    }

    public Time toTime() {
        return getTime(this.calendar);
    }
}
